@@ -7,13 +7,23 @@ from django.utils.text import capfirst
 from django.utils.datastructures import SortedDict
 from django.db.models import permalink
 from django.contrib.sites.models import Site
+from django.core.urlresolvers import reverse
 
 from properties import SchemaDesignChoiceField
-from scope import Scope
+from scope import Scope, get_site_scope
 
 import re
 import urlparse
 
+class ManageUrlsMixin(schema.Schema):
+    def get_manage_urls(self):
+        admin_name = '_'.join((self._meta.app_label, self._meta.module_name))
+        urls = {'add': reverse('admin:%s_add' % admin_name),
+                'list': reverse('admin:%s_changelist' % admin_name),}
+        if self.pk:
+            urls['edit'] = reverse('admin:%s_change' % admin_name, args=[self.pk])
+        return urls
+
 class SchemaDefMixin(schema.Schema):
     #_mixins = dict() #define on a document that implements mixins
     
@@ -165,7 +175,8 @@ class Collection(DocumentDesign, SchemaDefMixin):
         return 'dockitcms.virtual.%s' % self.key
     
     def get_document_kwargs(self, **kwargs):
-        kwargs = super(Collection, self).get_document_kwargs()
+        kwargs = super(Collection, self).get_document_kwargs(**kwargs)
+        kwargs.setdefault('attrs', dict())
         parents = list(kwargs.get('parents', list()))
         
         active_mixins = dict()
@@ -183,8 +194,19 @@ class Collection(DocumentDesign, SchemaDefMixin):
         if parents:
             kwargs['parents'] = tuple(parents)
         if active_mixins:
-            kwargs.setdefault('attrs', dict())
             kwargs['attrs']['_mixins'] = active_mixins
+        if self.application:
+            kwargs['app_label'] = self.application.name
+        
+        def get_manage_urls(instance):
+            base_url = self.get_admin_manage_url()
+            urls = {'add': base_url + 'add/',
+                    'list': base_url,}
+            if instance.pk:
+                urls['edit'] = base_url + instance.pk + '/'
+            return urls
+        
+        kwargs['attrs']['get_manage_urls'] = get_manage_urls
         return kwargs
     
     def register_collection(self):
@@ -216,7 +238,7 @@ class Collection(DocumentDesign, SchemaDefMixin):
         else:
             return self.__repr__()
 
-class Subsite(schema.Document, SchemaDefMixin):
+class Subsite(schema.Document, SchemaDefMixin, ManageUrlsMixin):
     url = schema.CharField()
     name = schema.CharField()
     sites = schema.ModelSetField(Site, blank=True)
@@ -228,7 +250,7 @@ class Subsite(schema.Document, SchemaDefMixin):
 
 Subsite.objects.index('sites').commit()
 
-class ViewPoint(schema.Document, SchemaDefMixin):
+class ViewPoint(schema.Document, SchemaDefMixin, ManageUrlsMixin):
     subsite = schema.ReferenceField(Subsite)
     url = schema.CharField(help_text='May be a regular expression that the url has to match')
     
@@ -250,9 +272,15 @@ class ViewPoint(schema.Document, SchemaDefMixin):
         pass
     
     def get_scopes(self):
-        return [Scope('site', object=Site.objects.get_current()),
-                Scope('subsite', object=self.subsite),
-                Scope('viewpoint', object=self)]
+        site_scope = get_site_scope()
+        
+        subsite_scope = Scope('subsite', object=self.subsite)
+        subsite_scope.add_data('object', self.subsite, self.subsite.get_manage_urls())
+        
+        viewpoint_scope = Scope('viewpoint', object=self)
+        viewpoint_scope.add_data('object', self, self.get_manage_urls())
+        
+        return [site_scope, subsite_scope, viewpoint_scope]
     
     def get_admin_view(self, **kwargs):
         from dockitcms.admin.views import ViewPointDesignerFragmentView
@@ -275,7 +303,7 @@ class ViewPoint(schema.Document, SchemaDefMixin):
     
     def reverse(self, name, *args, **kwargs):
         resolver = self.get_resolver()
-        return resolver.reverse(name, *args, **kwargs)
+        return self.full_url + resolver.reverse(name, *args, **kwargs)
     
     def save(self, *args, **kwargs):
         super(ViewPoint, self).save(*args, **kwargs)
